@@ -16,37 +16,28 @@
 # =*= License: GPL-3+ =*=
 
 
-
 import os
 
-import cliapp
-
 import vmdb
 
 
-class LvcreatePlugin(cliapp.Plugin):
-
+class LvcreatePlugin(vmdb.Plugin):
     def enable(self):
         self.app.step_runners.add(LvcreateStepRunner())
 
 
 class LvcreateStepRunner(vmdb.StepRunnerInterface):
-
     def get_key_spec(self):
-        return {
-            'lvcreate': str,
-            'name': str,
-            'size': str,
-        }
+        return {"lvcreate": str, "name": str, "size": str}
 
     def run(self, values, settings, state):
-        vgname = values['lvcreate']
-        lvname = values['name']
-        size = values['size']
+        vgname = values["lvcreate"]
+        lvname = values["name"]
+        size = values["size"]
 
-        vmdb.runcmd(['lvcreate', '--name', lvname, '--size', size, vgname])
+        vmdb.runcmd(["lvcreate", "-qq", "--name", lvname, "--size", size, vgname])
 
-        lvdev = '/dev/{}/{}'.format(vgname, lvname)
+        lvdev = "/dev/{}/{}".format(vgname, lvname)
         assert os.path.exists(lvdev)
         state.tags.append(lvname)
         state.tags.set_dev(lvname, lvdev)
